==> aws-sdk-cpp-1.11.686-1-x86_64.pkg.tar.zst: usr/include/aws/mediaconnect/MediaConnectErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/mediaconnect/MediaConnect_EXPORTS.h>

namespace Aws {
namespace MediaConnect {
enum class MediaConnectErrors {
  // From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7,                // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8,  // SDK should never allow
  MISSING_PARAMETER = 9,             // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ADD_FLOW_OUTPUTS420 = static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  BAD_REQUEST,
  CONFLICT,
  CREATE_BRIDGE420,
  CREATE_FLOW420,
  CREATE_GATEWAY420,
  FORBIDDEN,
  GRANT_FLOW_ENTITLEMENTS420,
  INTERNAL_SERVER_ERROR,
  NOT_FOUND,
  TOO_MANY_REQUESTS
};

class AWS_MEDIACONNECT_API MediaConnectError : public Aws::Client::AWSError<MediaConnectErrors> {
 public:
  MediaConnectError() {}
  MediaConnectError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<MediaConnectErrors>(rhs) {}
  MediaConnectError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<MediaConnectErrors>(rhs) {}
  MediaConnectError(const Aws::Client::AWSError<MediaConnectErrors>& rhs) : Aws::Client::AWSError<MediaConnectErrors>(rhs) {}
  MediaConnectError(Aws::Client::AWSError<MediaConnectErrors>&& rhs) : Aws::Client::AWSError<MediaConnectErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace MediaConnectErrorMapper {
AWS_MEDIACONNECT_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

}  // namespace MediaConnect
}  // namespace Aws

==> aws-sdk-cpp-1.11.744-1-x86_64.pkg.tar.zst: usr/include/aws/mediaconnect/MediaConnectErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/mediaconnect/MediaConnect_EXPORTS.h>

namespace Aws {
namespace MediaConnect {
enum class MediaConnectErrors {
  // From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7,                // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8,  // SDK should never allow
  MISSING_PARAMETER = 9,             // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ADD_FLOW_OUTPUTS420 = static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  BAD_REQUEST,
  CONFLICT,
  CREATE_BRIDGE420,
  CREATE_FLOW420,
  CREATE_GATEWAY420,
  FORBIDDEN,
  GRANT_FLOW_ENTITLEMENTS420,
  INTERNAL_SERVER_ERROR,
  NOT_FOUND,
  ROUTER_INPUT_SERVICE_QUOTA_EXCEEDED,
  ROUTER_NETWORK_INTERFACE_SERVICE_QUOTA_EXCEEDED,
  ROUTER_OUTPUT_SERVICE_QUOTA_EXCEEDED,
  TOO_MANY_REQUESTS
};

class AWS_MEDIACONNECT_API MediaConnectError : public Aws::Client::AWSError<MediaConnectErrors> {
 public:
  MediaConnectError() {}
  MediaConnectError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<MediaConnectErrors>(rhs) {}
  MediaConnectError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<MediaConnectErrors>(rhs) {}
  MediaConnectError(const Aws::Client::AWSError<MediaConnectErrors>& rhs) : Aws::Client::AWSError<MediaConnectErrors>(rhs) {}
  MediaConnectError(Aws::Client::AWSError<MediaConnectErrors>&& rhs) : Aws::Client::AWSError<MediaConnectErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace MediaConnectErrorMapper {
AWS_MEDIACONNECT_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

}  // namespace MediaConnect
}  // namespace Aws
